@@ -21,10 +21,24 @@ plot.kdeAlgo <- function(x, indicator = NULL, ...) {
 
   if(is.null(indicator)){
   for (i in 1:dim(x$Point_estimate.run)[1]) {
+   graphics::par(mfrow=c(2,1))
    name <- rownames(x$Point_estimate.run)
-   plot(x$Point_estimate.run[i,], xlab = "Iteration step", ylab = name[i],
-        main = "Convergence")
+   plot(x$Point_estimate.run[i,], xlab = "Iteration step",
+        ylab = "Point estimate for each iteration",
+        main = paste0("Convergence ", name[i]))
    abline(v = x$burnin)
+
+   means <- NULL
+   for (j in 1:x$samples){
+     means <- c(means, mean(x$Point_estimate.run[i,][x$burnin:j]))
+   }
+   point = c(rep(means[1]-.Machine$double.xmin, x$burnin),means)
+   plot(point,xlim = c(0, (x$burnin + x$samples)),
+        col = ifelse(point==means[1]-.Machine$double.xmin,'white','black'),
+        xlab = "Iteration step", ylab = "Average up to iterstion step M")
+   abline(h=x$Point_estimate[i])
+   abline(v=x$burnin)
+
    cat("Press [enter] to continue")
    line <- readline()
  }
@@ -33,14 +47,29 @@ plot.kdeAlgo <- function(x, indicator = NULL, ...) {
   if(!is.null(indicator)){
   for (i in 1:length(indicator)) {
       name <- indicator
-      plot(x$Point_estimate.run[indicator[i],], xlab = "Iteration step", ylab = name[i],
-           main = "Convergence")
+      graphics::par(mfrow=c(2,1))
+      plot(x$Point_estimate.run[indicator[i],], xlab = "Iteration step",
+           ylab = "Point estimate for each iteration",
+           main = paste0("Convergence ", name[i]))
       abline(v = x$burnin)
+
+      means <- NULL
+      for (j in 1:x$samples){
+        means <- c(means, mean(x$Point_estimate.run[indicator[i],][x$burnin:j]))
+      }
+      point = c(rep(means[1]-.Machine$double.xmin, x$burnin),means)
+      plot(point,xlim = c(0, (x$burnin + x$samples)),
+           col = ifelse(point==means[1]-.Machine$double.xmin,'white','black'),
+           xlab = "Iteration step", ylab = "Average up to iterstion step M")
+      abline(h=x$Point_estimate[indicator[i]])
+      abline(v=x$burnin)
+
       cat("Press [enter] to continue")
       line <- readline()
     }
 
   }
+  graphics::par(mfrow=c(1,1))
   classes <- x$classes
   xclass <- x$xclass
   if (max(classes) == Inf) {
